<?php

declare (strict_types = 1);

namespace App\Nova\Actions;

use App\Models\Product;
use Illuminate\Bus\Queueable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Support\Collection;
use Laravel\Nova\Actions\Action;
use Laravel\Nova\Fields\ActionFields;
use Laravel\Nova\Http\Requests\NovaRequest;

class ChangeValue extends Action
{
    use InteractsWithQueue, Queueable;

    public ?string $field;
    public ?string $retailer;

    public function __construct(?string $field, ?string $retailer)
    {
        $this->field = $field;
        $this->retailer = $retailer;
    }

    public function handle(ActionFields $fields, Collection $models)
    {
        if (!$this->isNotExistSameSKUOnDifferentRetailers($models)) {
            return Action::danger('You chose too much products with the same sku!');
        }
        foreach ($models as $model) {
            Product::where('retailer_id', $this->retailer)->where('sku', $model['sku'])->update([$this->field => $model[$this->field]]);
        }
        return Action::redirect('/');
    }

    /**
     * Get the fields available on the action.
     *
     * @param  \Laravel\Nova\Http\Requests\NovaRequest  $request
     * @return array
     */
    public function fields(NovaRequest $request)
    {
        return [];
    }

    private function isNotExistSameSKUOnDifferentRetailers(Collection $models)
    {
        $sku = [];
        foreach ($models as $model) {
            array_push($sku, $model['sku']);
        }
        $result = (count($sku) === count(array_unique($sku)));
        return ($result) ? true : false;
    }
}
