<?php

declare (strict_types = 1);

namespace App\Nova\Actions;

use App\Models\Retailer;
use Illuminate\Bus\Queueable;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Support\Collection;
use Laravel\Nova\Actions\Action;
use Laravel\Nova\Fields\ActionFields;
use Laravel\Nova\Fields\Select;
use Laravel\Nova\Http\Requests\NovaRequest;

class CompareActionChangeValues extends Action
{
    use InteractsWithQueue, Queueable;

    public $onlyOnIndex = true;

    public function handle(ActionFields $fields, Collection $models)
    {
        if (!$fields->changeField || !$fields->changeModel) {
            return Action::danger('All fields are required!');
        }
        return Action::redirect('compare-product?field=' . $fields->changeField . '&retailer=' . $fields->changeModel);
    }

    public function fields(NovaRequest $request)
    {
        return [
            Select::make('Model to change', 'changeModel')
                ->options(
                    Retailer::pluck('name', 'id')->all()
                )
                ->required(),
            Select::make('Field to change', 'changeField')
                ->options([
                    'price' => 'price',
                    'description' => 'description',
                    'name' => 'name',
                ])
                ->required(),
        ];

    }
}
